==> mili-4.0.1.tgz: package/es/src/util/readdeepdir.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as path from 'path';
import * as fs from 'fs-extra';
import * as R from 'ramda';
export function readdeepdir(dir, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const files = yield fs.readdir(dir);
        const promises = files.map((filename) => __awaiter(this, void 0, void 0, function* () {
            const filepath = path.join(dir, filename);
            if (options.filter && !(yield options.filter(filepath)))
                return [];
            const stat = yield fs.lstat(filepath);
            if (stat.isDirectory()) {
                const subfiles = yield readdeepdir(filepath);
                return subfiles.map(sub => path.join(filename, sub));
            }
            return filename;
        }));
        return R.unnest(yield Promise.all(promises));
    });
}

==> mili-4.5.1.tgz: package/es/src/util/readdeepdir.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as path from 'path';
import * as fs from 'fs-extra';
import * as R from 'ramda';
export function readdeepdir(dir, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const files = yield fs.readdir(dir);
        const promises = files.map((filename) => __awaiter(this, void 0, void 0, function* () {
            const filepath = path.join(dir, filename);
            if (options.filter && !(yield options.filter(filepath)))
                return [];
            const stat = yield fs.lstat(filepath);
            if (stat.isDirectory()) {
                const subfiles = yield readdeepdir(filepath, options);
                return subfiles.map(sub => path.join(filename, sub));
            }
            return filename;
        }));
        return R.unnest(yield Promise.all(promises));
    });
}
